@@ -713,3 +713,24 @@ dataset_collect <- function(dataset, iter_max = Inf) {
   out
 }
 
+#' Reduces the input dataset to a single element.
+#'
+#' The transformation calls reduce_func successively on every element of the input dataset
+#' until the dataset is exhausted, aggregating information in its internal state.
+#' The initial_state argument is used for the initial state and the final state is returned as the result.
+#'
+#' @param dataset A dataset
+#' @param initial_state An element representing the initial state of the transformation.
+#' @param reduce_func A function that maps `(old_state, input_element)` to new_state.
+#' It must take two arguments and return a new element.
+#' The structure of new_state must match the structure of initial_state.
+#'
+#' @return A dataset element.
+#'
+#' @family dataset methods
+#'
+#' @export
+dataset_reduce <- function(dataset, initial_state, reduce_func) {
+  dataset$`reduce`(initial_state, reduce_func)
+}
+
