@@ -23,4 +23,7 @@ tensorflow::shape
 #' @export
 tensorflow::install_tensorflow
 
+#' @importFrom generics fit
+#' @export
+generics::fit
 
